Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // Configuration represent the variable of configuration model Configuration = &ConfigurationModel{} )
Functions ¶
func InitMemcached ¶
InitMemcached will create a variable that represent the memcache.Client
Types ¶
type ConfigurationModel ¶
type ConfigurationModel struct {
Port string `json:"port"`
Memcached struct {
URL string `json:"url"`
} `json:"memcached"`
}
ConfigurationModel represent the configuration model
Click to show internal directories.
Click to hide internal directories.